import os
import shutil
from celery import states
from celery.exceptions import Ignore
from .common_task import CommonLuigiTask
import luigi
import json

def execute_task(celery_app, task_class: CommonLuigiTask, jsonstr_config: str):
    """Execute a luigi task and handle the success and error cases."""
    try:
        config = json.loads(jsonstr_config)
        task_instance = task_class(config=config)
        success = luigi.build([task_instance], local_scheduler=True)

        if not success:
            errlog_path = os.path.join(config.get('output_dir'), 'error.log')
            with open(errlog_path, 'r') as f:
                errlog = f.read()
            raise ValueError(errlog)

        message = "task completed"
        with task_instance.output().open('r') as f:
            data = json.load(f).get(task_instance.result_key(), {}) if success else {}

        return {
            "success": success,
            "detail": message,
            "data": data
        }

    except Exception as e:
        celery_app.update_state(state=states.FAILURE, meta={
            "exc_type": type(e).__name__,
            "exc_message": str(e)
        })
        raise Ignore()

    finally:
        if os.getenv('PRESERVE_OUTPUT', 'False').lower() != 'true':
            shutil.rmtree(config.get('output_dir'))



import os
import time
import shutil

# 특정 경로의 파일을 삭제하는 함수
def remove_if_old(path: str, age_limit: float, is_dir: bool = False):
    item_age = time.time() - os.path.getctime(path)
    
    if item_age > age_limit:
        try:
            if is_dir:
                shutil.rmtree(path)
                print(f"폴더 삭제됨: {path}")
            else:
                os.remove(path)
                print(f"파일 삭제됨: {path}")
        except Exception as e:
            print(f"삭제 실패: {path}, 오류: {e}")

# 지정 시간  이상된 파일 및 폴더 삭제
def cleanup_stale_items(path: str, hours: int = 1):
    if not os.path.exists(path):
        print(f"경로가 존재하지 않습니다: {path}")
        return
    age_limit = hours * 60 * 60
    # 파일 및 폴더 순회
    for root, dirs, files in os.walk(path, topdown=False):
        for file in files:
            remove_if_old(os.path.join(root, file), age_limit)
        for dir in dirs:
            remove_if_old(os.path.join(root, dir), age_limit, is_dir=True)

